testex_run: Run example tests

Description Usage Arguments Details

View source: R/testex.r

Description

Reruns all examples that have been originally evaluated and stored in an example test.

Usage

1
2
3
testex_run(et, log.file = "example_test_log.Rmd",
  stat.file = "example_test_stats.csv", parent.env = parent.frame(),
  exceptions = et$exceptions)

Arguments

et

An example test originally created with testex_create

log.file

The file name of the log. Should be an Rmd file.

stat.file

The name of the csv file that contains statistics about how many function calls of particular type failed.

parent.env

The parent environment in which examples are evaluated.

Details

Returns the number of calls that now return different values or throw an error and writes a detailed log as Rmd file.


skranz/testex documentation built on Oct. 7, 2020, 8:20 p.m.