| use_testex | R Documentation |
testex tags and configure package to fully use testex featuresAdd testex tags and configure package to fully use testex features
use_testex(path = getwd(), check = TRUE, quiet = FALSE)
path |
A package source code working directory |
check |
A |
quiet |
Whether output should be suppressed |
The result of write.dcf() upon modifying the package
DESCRIPTION file.
The testex roxygen2 tags behave similarly to roxygen2 @examples
tags, with the minor addition of some wrapping code to manage the tests. This
means that they will be integrated into your @examples and can be
intermixed between @examples tags
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.