| wrap_expect_no_error | R Documentation |
testthat expectation to not errorWraps an example expression in a testthat expectation to not error
wrap_expect_no_error(expr, value)
expr |
An expression to wrap in a |
value |
A symbol to use to store the result of |
A testthat::test_that() call
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.